/*****************************************************************
 * Copyright (c):   2009, All Rights Reserved.
 * Project:         Software Reverse Engineering (SRE) Education
 *                  Legacy Software Reengineering and Reuse
 *                  SimpleCalculator Java to COBOL Reuse Exercise
 * Programmer:      Teodoro Cipresso, San Jose State University
 *                  tcipress@hotmail.com
 ******************************************************************
 */
package info.reversingproject.jsimplecalculator;

import info.reversingproject.jsimplecalculator.jaxb.SmplCalcJaxbFactory;
import info.reversingproject.jsimplecalculator.jaxb.SMPLCALCINTERFACE;
import info.reversingproject.jsimplecalculator.jaxb.SmplCalcJaxbMarshaller;

import java.math.BigInteger;

public class JSimpleCalculator implements ISimpleCalculator {
    native String smplCalcXmlInterface(String xmldoc);

    static {
	System.loadLibrary("Java2CblXmlBridge");
    }

    /**
     */
    @Override
    public long doAdd(int _1stOp, int _2ndOp) throws ArithmeticException {
	if (JSimpleCalculatorUI._DEBUG_)
	    System.out.println(EOL + "[D] JSimpleCalculator.doAdd(" + _1stOp
		    + ", " + _2ndOp + ")");
	SMPLCALCINTERFACE addResult = invokeXmlInterface("+", _1stOp, _2ndOp);
	return addResult.getSIRESULT().longValue();
    }

    /**
     */
    @Override
    public long doSubtract(int _1stOp, int _2ndOp) throws ArithmeticException {
	if (JSimpleCalculatorUI._DEBUG_)
	    System.out.println(EOL + "[D] JSimpleCalculator.doSubtract("
		    + _1stOp + ", " + _2ndOp + ")");
	SMPLCALCINTERFACE subResult = invokeXmlInterface("-", _1stOp, _2ndOp);
	return subResult.getSIRESULT().longValue();
    }

    /**
     */
    @Override
    public long doMultiply(int _1stOp, int _2ndOp) throws ArithmeticException {
	if (JSimpleCalculatorUI._DEBUG_)
	    System.out.println(EOL + "[D] JSimpleCalculator.doMultiply("
		    + _1stOp + ", " + _2ndOp + ")");
	SMPLCALCINTERFACE mulResult = invokeXmlInterface("*", _1stOp, _2ndOp);
	return mulResult.getSIRESULT().longValue();
    }

    /**
   */
    public SMPLCALCINTERFACE invokeXmlInterface(String calcType, int _1stOp,
	    int _2ndOp) {
	if (JSimpleCalculatorUI._DEBUG_)
	    System.out.println(EOL
		    + "[D] JSimpleCalculator.invokeXmlInterface(" + calcType
		    + ", " + _1stOp + ", " + _2ndOp + ")");
	SMPLCALCINTERFACE inputData = new SmplCalcJaxbFactory()
		.createSMPLCALCINTERFACE();
	inputData.setSIOPERATION(calcType);
	inputData.setSIOPERAND1(BigInteger.valueOf(_1stOp));
	inputData.setSIOPERAND2(BigInteger.valueOf(_2ndOp));
	inputData.setSIRESULTMESSAGE("");
	inputData.setSIRESULT(BigInteger.valueOf(0));
	String inputXml = SmplCalcJaxbMarshaller.serializeXML(inputData);
	if (JSimpleCalculatorUI._DEBUG_)
	    System.out
		    .println(EOL
			    + "[D] JSimpleCalculator.invokeXmlInterface(): Before call to Java2CblXmlBridge");
	String outputXml = smplCalcXmlInterface(inputXml);
	if (JSimpleCalculatorUI._DEBUG_)
	    System.out
		    .println(EOL
			    + "[D] JSimpleCalculator.invokeXmlInterface(): After call to Java2CblXmlBridge");
	SMPLCALCINTERFACE outputData = SmplCalcJaxbMarshaller
		.loadXML(outputXml);
	return outputData;
    }

    public static String EOL = System.getProperty("line.separator");

}
