/*****************************************************************
 * Copyright (c):   2009, All Rights Reserved.
 * Project:         Software Reverse Engineering (SRE) Education
 *                  Legacy Software Reengineering and Reuse
 *                  SimpleCalculator Java to COBOL Reuse Exercise
 * Programmer:      Teodoro Cipresso, San Jose State University
 *                  tcipress@hotmail.com
 ******************************************************************
 */
package info.reversingproject.jsimplecalculator;

import java.io.BufferedReader;
import java.io.InputStreamReader;

public class JSimpleCalculatorUI implements ISimpleCalculatorUI {

    public static boolean _DEBUG_ = true;

    public static String EOL = System.getProperty("line.separator");

    /**
   */
    public static void main(String[] args) {
	JSimpleCalculatorUI simpleCalcUI = new JSimpleCalculatorUI();
	simpleCalcUI.run();
    }

    /**
   */
    private void run() {
	// create calculator proxy instance
	JSimpleCalculator simpleCalc = new JSimpleCalculator();
	// program loop
	boolean exitProgram = false;
	while (!exitProgram) {
	    int selection = doGetUserMenuSelection();
	    int _1stOp = 0;
	    int _2ndOp = 0;
	    long calcResult = 0;
	    switch (selection) {
	    case ISimpleCalculatorUI.DO_ADD_MENU_ITEM:
		_1stOp = getIntegerOperand(1);
		_2ndOp = getIntegerOperand(2);
		calcResult = simpleCalc.doAdd(_1stOp, _2ndOp);
		System.out.println(EOL + "[***] COBOL addition result: "
			+ calcResult + EOL);
		break;
	    case ISimpleCalculatorUI.DO_SUBTRACT_MENU_ITEM:
		_1stOp = getIntegerOperand(1);
		_2ndOp = getIntegerOperand(2);
		calcResult = simpleCalc.doSubtract(_1stOp, _2ndOp);
		System.out.println(EOL + "[***] COBOL subtraction result: "
			+ calcResult + EOL);
		break;
	    case ISimpleCalculatorUI.DO_MULTIPLY_MENU_ITEM:
		_1stOp = getIntegerOperand(1);
		_2ndOp = getIntegerOperand(2);
		calcResult = simpleCalc.doMultiply(_1stOp, _2ndOp);
		System.out.println(EOL + "[***] COBOL multiplication result: "
			+ calcResult + EOL);
		break;
	    case ISimpleCalculatorUI.DO_QUIT_PROGRAM_MENU_ITEM:
		exitProgram = true;
		System.out.println(EOL + "[I] Quitting..." + EOL);
		break;
	    case ISimpleCalculatorUI.DO_TOGGLE_DEBUG_MODE:
		_DEBUG_ = !(_DEBUG_);
		System.out.println(EOL + "[I] Debug mode now "
			+ ((_DEBUG_) ? "ON" : "OFF") + "." + EOL);
		break;
	    default:
		System.out.println(EOL + "[!] Invalid menu selection." + EOL);
	    } // switch
	} // while
    } // run()

    /**
   */
    public int doGetUserMenuSelection() {
	System.out.println("");
	System.out.println("****************************************************");
	System.out.println("** Program: Java Front-end to COBOL Calculator    **");
	System.out.println("** Purpose: Demonstrate reengineering and reuse   **");
	System.out.println("**          of a COBOL program from Java by       **");
	System.out.println("**          establishing an XML bridge leveraging **");
	System.out.println("**          JAXB, JNI, and COBOL XML support.     **");	
	System.out.println("** Author:  Teodoro Cipresso                      **");
	System.out.println("**          tcipress@hotmail.com                  **");
	System.out.println("****************************************************");
	System.out.println("");
	System.out.println("Select a task from the following menu:");
	System.out.println("");
	System.out.println("(1) Addition");
	System.out.println("(2) Subtraction");
	System.out.println("(3) Multiplication");
	System.out.println("(4) Toggle Debug " + ((!_DEBUG_) ? "ON" : "OFF"));
	System.out.println("(5) Quit Program");
	System.out.println("");
	System.out.print("Specify selection: ");
	int selection = 0;
	try {
	    selection = Integer.parseInt(getConsoleInputLine());
	} catch (NumberFormatException _e) {
	    selection = -1;
	}
	return selection;
    } // doGetUserMenuSelection()

    /**
   */
    public int getIntegerOperand(int operandNum) throws NumberFormatException {
	System.out.print(EOL + "Specify integer operand #" + operandNum + ": ");
	int operand = 0;
	try {
	    operand = Integer.parseInt(getConsoleInputLine());
	} catch (NumberFormatException _e) {
	    throw _e;
	}
	return operand;
    } // getFirstOperand()

    /**
   */
    private static String getConsoleInputLine() {
	String consoleInput = null;
	InputStreamReader inputReader = new InputStreamReader(System.in);
	BufferedReader bufferedReader = new BufferedReader(inputReader);
	try {
	    consoleInput = bufferedReader.readLine();
	} catch (Exception _exception) {
	    _exception.printStackTrace();
	}
	return consoleInput;
    } // getConsoleInputLine()

}
