/*****************************************************************
 * Copyright (c):   2009, All Rights Reserved.
 * Project:         Software Reverse Engineering (SRE) Education
 *                  Legacy Software Reengineering and Reuse
 *                  SimpleCalculator Java to COBOL Reuse Exercise
 * Programmer:      Teodoro Cipresso, San Jose State University
 *                  tcipress@hotmail.com
 ******************************************************************
 */
package info.reversingproject.jsimplecalculator.jaxb;

import info.reversingproject.jsimplecalculator.JSimpleCalculatorUI;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;

public class SmplCalcJaxbMarshaller {

    public static String EOL = System.getProperty("line.separator");

    //
    private static JAXBContext jaxbContext = null;
    private static Marshaller marshaller = null;
    private static Unmarshaller unmarshaller = null;

    static { // we only need to initialize the marshaller once
	try { // instantiate JAXB marshalling classes
	    jaxbContext = JAXBContext.newInstance(SMPLCALCINTERFACE.class);
	    marshaller = jaxbContext.createMarshaller();
	    unmarshaller = jaxbContext.createUnmarshaller();
	} catch (Exception _e) { // couldn't create marshaller
	    System.out
		    .println(EOL
			    + "[!] An error occurred while initializing JAXB marshalling.");
	    _e.printStackTrace();
	    System.exit(0);
	} // try
    } // static

    /**
   */
    public static String serializeXML(SMPLCALCINTERFACE request) {
	if (JSimpleCalculatorUI._DEBUG_)
	    System.out.println(EOL
		    + "[D] SmplCalcJaxbMarshaller.serializeXML()");
	ByteArrayOutputStream xmlBytes = new ByteArrayOutputStream();
	try {
	    marshaller.marshal(request, xmlBytes);
	} catch (JAXBException _je) {
	    System.out.println(EOL
		    + "[!] An error occurred during Java to XML marshalling.");
	    _je.printStackTrace();
	    System.exit(0);
	}
	String xmlDoc = new String(xmlBytes.toByteArray());
	if (JSimpleCalculatorUI._DEBUG_)
	    System.out.println(EOL
		    + "[D] SmplCalcJaxbMarshaller.serializeXML().xmlDoc["
		    + xmlDoc + "]");
	return xmlDoc;
    }

    /**
   */
    public static SMPLCALCINTERFACE loadXML(String xmlDoc) {
	if (JSimpleCalculatorUI._DEBUG_)
	    System.out.println(EOL
		    + "[D] SmplCalcJaxbMarshaller.loadXML().xmlDoc[" + xmlDoc
		    + "]");
	SMPLCALCINTERFACE response = null;
	ByteArrayInputStream xmlBytes = new ByteArrayInputStream(xmlDoc
		.getBytes());
	try {
	    response = (SMPLCALCINTERFACE) unmarshaller.unmarshal(xmlBytes);
	} catch (JAXBException _je) {
	    System.out.println(EOL
		    + "[!] An error occurred during XML to Java marshalling.");
	    _je.printStackTrace();
	    System.out.println(xmlDoc);
	    System.exit(0);
	}
	return response;
    }

}
